==> strupy-0.5.7.zip: strupy-0.5.7/strupy/pill.py <==
'''
--------------------------------------------------------------------------
Copyright (C) 2015 Lukasz Laba <lukaszlab@o2.pl>

File version 0.1 date 2016-01-xx

This file is part of StruPy.
StruPy is a structural engineering design Python package.
http://strupy.org/

StruPy is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

StruPy is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Foobar; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------
File version 0.2 changes:
- ........
'''

import strupy.units as u

from strupy.steel.MaterialSteel import MaterialSteel as __MaterialSteel
MaterialSteel = __MaterialSteel()

from strupy.steel.SectionBase import SectionBase as __SectionBase
SectionBase = __SectionBase()

from strupy.concrete.MaterialConcrete import MaterialConcrete as __MaterialConcrete
MaterialConcrete = __MaterialConcrete()

from strupy.concrete.MaterialRcsteel import MaterialRcsteel as __MaterialRcsteel
MaterialRcsteel = __MaterialRcsteel()

import strupy.concrete.rcsteel_area as rcsteel_area


# Test if main
if __name__ == '__main__':
    pass

==> strupy-0.5.8.zip: strupy-0.5.8/strupy/pill.py <==
'''
--------------------------------------------------------------------------
Copyright (C) 2015 Lukasz Laba <lukaszlab@o2.pl>

This file is part of StruPy.
StruPy structural engineering design Python package.
https://bitbucket.org/struthonteam/strupy

StruPy is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

StruPy is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with StruPy; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------
File version 0.2 changes:
- ........
'''

import strupy.units as u

from strupy.steel.MaterialSteel import MaterialSteel as __MaterialSteel
MaterialSteel = __MaterialSteel()

from strupy.steel.SectionBase import SectionBase as __SectionBase
SectionBase = __SectionBase()

from strupy.concrete.MaterialConcrete import MaterialConcrete as __MaterialConcrete
MaterialConcrete = __MaterialConcrete()

from strupy.concrete.MaterialRcsteel import MaterialRcsteel as __MaterialRcsteel
MaterialRcsteel = __MaterialRcsteel()

import strupy.concrete.rcsteel_area as rcsteel_area


# Test if main
if __name__ == '__main__':
    pass
